import UIKit

// MARK: - Enum Extensions for Logging

// Add a `description` property to the `NSLocale.LanguageDirection` enum, so we can print the language directions nicely.
public extension NSLocale.LanguageDirection
{
    public var description: String
    {
        switch self {
        case .unknown:
            return "?"
        case .bottomToTop:
            return "⬆️"
        case .topToBottom:
            return "⬇️"
        case .leftToRight:
            return "➡️"
        case .rightToLeft:
            return "⬅️"
        }
    }
}

// Add a `description` property to the `UIUserInterfaceLayoutDirection` enum, so we can print the language directions nicely.
public extension UIUserInterfaceLayoutDirection
{
    public var description: String
    {
        switch self {
        case .leftToRight:
            return "➡️"
        case .rightToLeft:
            return "⬅️"
        }
    }
}

// Add a `description` property to the `UIUserInterfaceLayoutDirection` enum, so we can print the language directions nicely.
public extension NSWritingDirection
{
    public var description: String
    {
        switch self {
        case .natural:
            return "⚙ (UIApplication reports \(UIApplication.shared.userInterfaceLayoutDirection.description))"
        case .leftToRight:
            return "➡️"
        case .rightToLeft:
            return "⬅️"
            
            
        }
    }
}
